import rlcompleter, readline
readline.parse_and_bind('tab:complete')
import numpy as np
import matplotlib.pyplot as plt
from scipy.interpolate import griddata

from pyhdf.SD import *

execfile('input_fcc.py')

SDS_NAME340='BRDF_Reflectance_lambda340'
SDS_NAME380='BRDF_Reflectance_lambda380'
SDS_NAME470='BRDF_Reflectance_lambda470'
SDS_NAME680='BRDF_Reflectance_lambda680'
SDS_NAME870='BRDF_Reflectance_lambda870'
SDS_NAME1036='BRDF_Reflectance_lambda1036'
SDS_NAME1219='BRDF_Reflectance_lambda1219'
SDS_NAME1275='BRDF_Reflectance_lambda1275'
SDS_NAME=((SDS_NAME340,SDS_NAME380,SDS_NAME470,SDS_NAME680,SDS_NAME870,SDS_NAME1036,SDS_NAME1219,SDS_NAME1275))

nphi=360.0/del_phi
ntheta=90.0/del_theta+1

inputfile=datadir+inputfile
fcc_data=np.zeros((nphi,ntheta,3))

hdf=SD(inputfile)
sds=hdf.select(SDS_NAME[band_index_for_Red])
data=sds.get()
if(space==0):
 fcc_data[:,:,0]=data[0:ntheta,0:nphi].T
else:
 fcc_data[:,:,0]=data[ntheta-1:2*ntheta-1,0:nphi][::-1,:].T

sds=hdf.select(SDS_NAME[band_index_for_Green])
data=sds.get()
if(space==0):
 fcc_data[:,:,1]=data[0:ntheta,0:nphi].T
else:
 fcc_data[:,:,1]=data[ntheta-1:2*ntheta-1,0:nphi][::-1,:].T

sds=hdf.select(SDS_NAME[band_index_for_Blue])
data=sds.get()
if(space==0):
 fcc_data[:,:,2]=data[0:ntheta,0:nphi].T
else:
 fcc_data[:,:,2]=data[ntheta-1:2*ntheta-1,0:nphi][::-1,:].T


def default_linear_stretch(in_data,out_data):
 minimum=np.nanmin(in_data)
 maximum=np.nanmax(in_data)
 out_data=0.0+(in_data-minimum)/(maximum-minimum)*(1.0-0.0)
 return out_data

def linear_stretch(input_data,nBreak,input_break,output_break):
 fcc_scaled_temp=np.zeros(input_data.shape)
 a=np.nanmin(input_data)
 b=np.nanmax(input_data)
 input_break[0]=a
 input_break[nBreak+1]=b
 for i in range(0,nBreak+1):
  mask1=input_data>input_break[i]
  mask2=input_data<=input_break[i+1]
  mask=mask1*mask2
  I1=input_break[i]
  I2=input_break[i+1]
  O1=output_break[i]
  O2=output_break[i+1]
  fcc_scaled_temp[mask]=O1+(input_data[mask]-I1)/(I2-I1)*(O2-O1)
  print I1,I2,O1,O2
 return fcc_scaled_temp

fcc_data_scaled=np.zeros(fcc_data.shape)
if(default==0):
 fcc_data_scaled=default_linear_stretch(fcc_data,fcc_data_scaled)
else:
 fcc_data_scaled[:,:,0]=linear_stretch(fcc_data[:,:,0],nRed,red_break_input,red_break_output)
 fcc_data_scaled[:,:,1]=linear_stretch(fcc_data[:,:,1],nGreen,green_break_input,green_break_output)
 fcc_data_scaled[:,:,2]=linear_stretch(fcc_data[:,:,2],nBlue,blue_break_input,blue_break_output)

r=np.arange(0,ntheta,1)
theta=np.arange(0,nphi,1)*np.pi/180


nr=int(ntheta)
nt=int(nphi)
x1=np.zeros((nphi*ntheta))
y1=np.zeros((nphi*ntheta))
data1=np.zeros((nphi*ntheta))
data2=np.zeros((nphi*ntheta))
data3=np.zeros((nphi*ntheta))
for i in range(0,nr):
 for j in range(0,nt):
  k=i*nt+j
  x1[k]=r[i]*np.cos(theta[j])
  y1[k]=r[i]*np.sin(theta[j])
  data1[k]=fcc_data_scaled[j,i,0]
  data2[k]=fcc_data_scaled[j,i,1]
  data3[k]=fcc_data_scaled[j,i,2]

xa=x1.min()
xb=x1.max()
ya=y1.min()
yb=y1.max()

x=np.linspace(xa,xb,720)
y=np.linspace(ya,yb,720)

points=np.zeros((nt*nr,2))
for i in range(0,nr):
 for j in range(0,nt):
  k=i*nt+j
  points[k,0]=x1[k]
  points[k,1]=y1[k]

#data1=np.zeros((nt*nr))
#for i in range(0,nr):
# for j in range(0,nt):
#  k=i*nt+j
#  data1[k]=variable[j,i,0]

#data1[data1==0]=0.01

out_point=np.zeros((720*720,2))
for i in range(0,720):
 for j in range(0,720):
  k=i*720+j
  out_point[k,0]=x[i]
  out_point[k,1]=y[j]

data=np.zeros((720,720,3))

mask1=~np.isnan(data1)
mask2=~np.isnan(data2)
mask3=~np.isnan(data3)

temp1=griddata(points[mask1,:],data1[mask1],out_point, method='cubic')
temp2=griddata(points[mask2,:],data2[mask2], out_point,method='cubic')
temp3=griddata(points[mask3,:],data3[mask3],out_point, method='cubic')
for i in range(0,720):
 k1=i*720
 k2=(i+1)*720
 data[i,:,0]=temp1[k1:k2]
 data[i,:,1]=temp2[k1:k2]
 data[i,:,2]=temp3[k1:k2]

data[np.isnan(data)]=1.0

data2=data[::-1,:,:]

fig = plt.figure(figsize=(8,8))
plt.imshow(data2)
plt.xticks([])
plt.yticks([])
plt.axis('off')
plt.savefig(output_filename, dpi=dpi,bbox_inches='tight', pad_inches=0,format='png')
plt.clf()

